@@ -10,4 +10,7 @@
 /*                                                                       */
 /*************************************************************************/
 
-int lg_expand_disjunct_list(Sentence sent);
+/* Defined in link-includes.h */
+/* int lg_expand_disjunct_list(Sentence sent); */
+
+#include <link-grammar/link-includes.h>
